@@ -7,7 +7,7 @@ import logging
 class FilterData :
 
         def getJsonSites():
-            with open(os.path.dirname(__file__) + '/SITES_EDGES_BANCOLOMBIA.json', 'r') as archive:
+            with open(os.path.join(os.path.dirname(__file__),'..'+ '/SITES_EDGES_BANCOLOMBIA.json') , 'r') as archive:
                 data = json.load(archive)
                 return data
 
